@@ -46,20 +46,6 @@
 #' @name grid_shape_grobs
 NULL
 
-halma_xy <- function() {
-    y_cutoff <- 0.55
-    y_frac <- 0.5
-    t <- rev(seq(0, 360, length.out=100) - 90)
-    r <- 0.5
-    x <- 0.5 + to_x(t, r)
-    y <- 1 + y_frac * (to_y(t, r) - r)
-    indices <- which(y >= y_cutoff)
-    list(x = c(0,0, x[indices],1,1), y=c(0,0.3,y[indices],0.3,0))
-}
-pyramid_xy <- list(x = c(0, 0.5, 1), y = c(0, 1, 0))
-kite_xy <- list(x = c(0.5, 0, 0.5, 1), y = c(0, 0.25, 1, 0.25))
-# rect_xy <- function() { list(x = c(0, 0, 1, 1), y=c(0, 1, 1, 0)) } # nolint
-
 #' @rdname grid_shape_grobs
 #' @export
 halmaGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
@@ -67,28 +53,25 @@ halmaGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
     polygonGrob(xy$x, xy$y, name=name, gp=gp, vp=vp)
 }
 
-#' @rdname grid_shape_grobs
-#' @export
-pyramidGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
-    polygonGrob(x = pyramid_xy$x, y = pyramid_xy$y, name=name, gp=gp, vp=vp)
-}
-
 #' @rdname grid_shape_grobs
 #' @export
 kiteGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
     polygonGrob(kite_xy$x, kite_xy$y, name=name, gp=gp, vp=vp)
 }
 
-polygonGrobFn <- function(x, y) {
-    function(name=NULL, gp=gpar(), vp=NULL) polygonGrob(x, y, name=name, gp=gp, vp=vp)
+ovalGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
+    xy <- oval_xy()
+    polygonGrob(xy$x, xy$y, name=name, gp=gp, vp=vp)
 }
 
-convex_xy <- function(n_vertices, t) {
-    t <- seq(0, 360, length.out=n_vertices+1) + t
-    r <- 0.5
-    x <- to_x(t, r) + 0.5
-    y <- to_y(t, r) + 0.5
-    list(x=utils::head(x, -1), y=utils::head(y, -1))
+#' @rdname grid_shape_grobs
+#' @export
+pyramidGrob <- function(name=NULL, gp=gpar(), vp=NULL) {
+    polygonGrob(x = pyramid_xy$x, y = pyramid_xy$y, name=name, gp=gp, vp=vp)
+}
+
+polygonGrobFn <- function(x, y) {
+    function(name=NULL, gp=gpar(), vp=NULL) polygonGrob(x, y, name=name, gp=gp, vp=vp)
 }
 
 #' @rdname grid_shape_grobs
@@ -98,19 +81,6 @@ convexGrobFn <- function(n_vertices, t) {
     polygonGrobFn(xy$x, xy$y)
 }
 
-concave_xy <- function(n_vertices, t, r=0.2) {
-    t_outer <- seq(0, 360, length.out=n_vertices+1) + t
-    n_degrees <- 360 / n_vertices / 2
-    t_inner <- seq(n_degrees, 360-n_degrees, length.out=n_vertices) + t
-    x_outer <- to_x(t_outer, 0.5) + 0.5
-    x_inner <- to_x(t_inner,   r) + 0.5
-    y_outer <- to_y(t_outer, 0.5) + 0.5
-    y_inner <- to_y(t_inner,   r) + 0.5
-    x <- splice(x_outer, x_inner)
-    y <- splice(y_outer, y_inner)
-    list(x=x, y=y)
-}
-
 #' @rdname grid_shape_grobs
 #' @export
 concaveGrobFn <- function(n_vertices, t, r=0.2) {
@@ -118,20 +88,10 @@ concaveGrobFn <- function(n_vertices, t, r=0.2) {
     polygonGrobFn(xy$x, xy$y)
 }
 
-splice <- function(x0, x1) {
-    vec <- as.numeric()
-    for (ii in seq_along(x1)) {
-        vec <- append(vec, x0[ii])
-        vec <- append(vec, x1[ii])
-    }
-    append(vec, x0[ii+1])
-}
-
 halmaMatGrobFn <- function(width=0.2) {
     width <- rep(width, length.out=2)
     xy_out <- halma_xy()
-    xy_in <- unit_to_cartesian_coords(xy_out$x, xy_out$y,
-                                 height=1-width[1], width=1-2.5*width[2])
+    xy_in <- Point$new(xy_out)$npc_to_in(h=1-width[1], w=1-2.5*width[2])
     x <- c(xy_in$x, xy_out$x)
     y <- c(xy_in$y, xy_out$y)
     id <- rep(1:2, each=length(xy_out$x))
