@@ -4,6 +4,7 @@ test_that("options work as expected", {
                 suit_color = "darkred,black,darkgreen,darkblue,grey")
     expect_equal(get_suit_color("coin_back", 1, 1, cfg), "white")
     expect_equal(get_suit_color("coin_face", 5, 1, cfg), "grey")
+    expect_equal(pp_cfg(cfg)$get_suit_color(3:2), c("darkgreen", "black"))
 
     expect_equal(should_invert("coin_back", 1, 1, list()), FALSE)
     expect_equal(should_invert("coin_back", 1, 1, list(invert_colors = TRUE)), TRUE)
@@ -58,16 +59,12 @@ test_that("get_piece_opt works as expected", {
     opt <- cfg$get_piece_opt("coin_face")
     expect_equal(opt$background_col, "white")
     expect_equal(opt$border_col, "grey")
-    expect_equal(opt$gridline_col, "transparent") 
+    expect_equal(opt$gridline_col, "transparent")
     expect_equal(opt$ps_col, "grey")
     expect_equal(opt$ps_text, "n")
     expect_equal(opt$ps_fontsize, 28)
     expect_equal(opt$ps_fontfamily, "sans")
     expect_equal(opt$ps_fontface, "plain")
-    # expect_equal(opt$suit_symbol, "\u2605")
-    # expect_equal(opt$suit_symbol, "\u263c")
-    # expect_equal(opt$suit_fontsize, 24)
-    # expect_equal(opt$suit_font, "sans")
     expect_equal(opt$dm_col, "grey")
     expect_equal(opt$dm_text, "\u25cf")
     expect_equal(opt$shape, "circle")
@@ -85,12 +82,20 @@ test_that("get_piece_opt works as expected", {
     cfg <- pp_cfg()
     opt <- cfg$get_piece_opt("saucer_back")
     expect_equal(opt$dm_text, "\u25b2")
-    # expect_equal(opt$dm_text, "\u265f")
     opt <- cfg$get_piece_opt("pawn_face")
     expect_equal(opt$dm_text, "\u0298\u0298")
-    # expect_equal(opt$dm_text, "\U0001f440")
     opt <- cfg$get_piece_opt("pawn_back")
     expect_equal(opt$dm_text, "")
+
+    cfg <- pp_cfg(list(suit_color="white"))
+    opt <- cfg$get_piece_opt("tile_face", suit=2, rank=2)
+    expect_equal(opt$ps_col, "white")
+    cfg <- pp_cfg(list(suit_color.suited="white"))
+    opt <- cfg$get_piece_opt("tile_face", suit=2, rank=2)
+    expect_equal(opt$ps_col, "white")
+    cfg <- pp_cfg(list(suit_color.s2="white"))
+    opt <- cfg$get_piece_opt("tile_face", suit=2, rank=2)
+    expect_equal(opt$ps_col, "white")
 })
 
 context("pp_cfg querying variables work as expected")
@@ -116,4 +121,5 @@ test_that("pp_cfg querying variables work as expected", {
     expect_false(cfg$has_saucers)
     expect_false(cfg$has_pyramids)
     expect_false(cfg$has_matchsticks)
+    expect_error(cfg$has_piecepack <- 3, "3 is not logical")
 })
